# Generated by Django 5.2.8 on 2026-03-08 08:40

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('log', '0008_activity_log_activity'),
    ]

    operations = [
        migrations.AlterField(
            model_name='activity',
            name='model',
            field=models.CharField(blank=True, help_text='Information about the triggering model, log lines can have deviating modelsCombination of app label and model name separated by a dot.', max_length=255, null=True, verbose_name='Model'),
        ),
        migrations.AlterField(
            model_name='log',
            name='model',
            field=models.CharField(help_text='Combination of app label and model name separated by a dot', max_length=255, verbose_name='Model'),
        ),
        migrations.AlterField(
            model_name='logconfig',
            name='model',
            field=models.CharField(help_text='Combination of app label and model name separated by a dot', max_length=255, verbose_name='Model'),
        ),
    ]
