<table>
    <tbody>
        {% for row in table_data.body.rows %}
            <tr hx-swap-oob="innerHTML:#tr-{{ row.id }}">
                {% include 'ui/table.html#td' with row=row %}
            </tr>
        {% endfor %}
    </tbody>
    {% if footer %}
        <tfoot>
            <tr hx-swap-oob="innerHTML:#tf-row">
                {% include 'ui/table.html#tf' with table_data=table_data %}
            </tr>
        </tfoot>
    {% endif %}
</table>
