<div class="navbar-item is-unselectable has-text-weight-bold" style="{% if switch_url %}cursor: pointer;{% endif %}" x-on:click="showQuickSwitch = !showQuickSwitch;">
    {{ tenant.name }}
</div>
{% if tenants and switch_url %}
<article class="box p-1" style="position: fixed; top: var(--bulma-navbar-height); left: 0; min-width: 150px; border-radius: 0 0 var(--bulma-radius) 0;"
         x-show="showQuickSwitch" x-cloak="" x-on:click.outside="showQuickSwitch = false"
>
    <ul class="hoverable">
        {% for t in tenants %}
            <li class="navbar-item has-text-weight-medium" style="cursor: pointer; border-radius: var(--bulma-radius); color: unset;"><a href="{{ switch_url }}?tenant_id={{ t.pk }}" hx-boost="false" style="width: 100%; display: inline-block">{{ t.name }}</a></li>
        {% endfor %}
    </ul>
</article>
{% endif %}