# Generated by Django 5.2.7 on 2025-10-05 21:45

from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('accrete', '0010_alter_accessgroup_description'),
        ('log', '0005_logconfig_exclude_fields_and_more'),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.RemoveIndex(
            model_name='log',
            name='accrete_log_model_cf888c_idx',
        ),
        migrations.AddIndex(
            model_name='log',
            index=models.Index(fields=['model', 'object_id', 'tenant_id'], name='accrete_log_model_22d992_idx'),
        ),
    ]
