# Generated by Django 5.2.1 on 2025-08-08 06:13

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('user', '0009_alter_user_theme'),
    ]

    operations = [
        migrations.AlterField(
            model_name='user',
            name='theme',
            field=models.CharField(choices=[('preset', 'Preset'), ('light', 'Light'), ('dark', 'Dark'), ('custom', 'Custom')], default='preset', max_length=50, verbose_name='Theme'),
        ),
    ]
