{% if oob.wrap %}<{{ oob.tag|default_if_none:'div' }} hx-swap-oob="{{ oob.swap|default_if_none:'true' }}" {% for k, v in oob.attrs.items %}{{ k }}="{{ v }}"{% endfor %}>{% endif %}
    {% include oob.template %}
{% if oob.wrap %}</{{ oob.tag|default_if_none:'div' }}>{% endif %}