# Generated by Django 5.2.5 on 2025-10-03 07:29

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('ui', '0004_theme_force_tenant_theme'),
    ]

    operations = [
        migrations.AddField(
            model_name='theme',
            name='base_theme',
            field=models.CharField(choices=[('light', 'Light'), ('dark', 'Dark')], default='light', verbose_name='Base Theme'),
        ),
    ]
