# Generated by Django 5.2.8 on 2026-03-08 08:40

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('ui', '0005_theme_base_theme'),
    ]

    operations = [
        migrations.AddField(
            model_name='theme',
            name='navbar_color',
            field=models.CharField(blank=True, choices=[('is-primary', 'Primary'), ('is-success', 'Success'), ('is-link', 'Link'), ('is-warning', 'Warning'), ('is-danger', 'Danger')], default='is-primary', null=True, verbose_name='Navbar Color'),
        ),
    ]
