# Generated by Django 5.1.7 on 2025-03-23 08:11

import accrete.contrib.user.models
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('user', '0007_user_managed_login'),
    ]

    operations = [
        migrations.RemoveConstraint(
            model_name='user',
            name='no_email_for_managed_user',
        ),
        migrations.AlterField(
            model_name='user',
            name='language_code',
            field=models.CharField(blank=True, default=accrete.contrib.user.models.default_language_code, max_length=10, null=True, verbose_name='Language'),
        ),
    ]
