# Generated by Django 5.2.1 on 2025-08-08 06:27

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('ui', '0003_alter_theme_check_user_or_tenant'),
    ]

    operations = [
        migrations.AddField(
            model_name='theme',
            name='force_tenant_theme',
            field=models.BooleanField(default=False, help_text='Apply this theme regardless of user preferences', verbose_name='Force Tenant Theme'),
        ),
    ]
