# Generated by Django 5.2.1 on 2025-08-07 17:11

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('ui', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='theme',
            name='color_danger',
            field=models.CharField(default='#FF6584', max_length=7, verbose_name='Danger Color'),
        ),
        migrations.AlterField(
            model_name='theme',
            name='color_link',
            field=models.CharField(default='#65D0FE', max_length=7, verbose_name='Link Color'),
        ),
        migrations.AlterField(
            model_name='theme',
            name='color_primary',
            field=models.CharField(default='#46C68D', max_length=7, verbose_name='Primary Color'),
        ),
        migrations.AlterField(
            model_name='theme',
            name='color_success',
            field=models.CharField(default='#46C68D', max_length=7, verbose_name='Success Color'),
        ),
        migrations.AlterField(
            model_name='theme',
            name='color_warning',
            field=models.CharField(default='#FEB600', max_length=7, verbose_name='Warning Color'),
        ),
    ]
