<style>
    :root {
        --bulma-primary-h: {{ primary.h }}deg;
        --bulma-primary-s: {{ primary.s }}%;
        --bulma-primary-l: {{ primary.l }}%;
        --bulma-success-h: {{ success.h }}deg;
        --bulma-success-s: {{ success.s }}%;
        --bulma-success-l: {{ success.l }}%;
        --bulma-link-h: {{ link.h }}deg;
        --bulma-link-s: {{ link.s }}%;
        --bulma-link-l: {{ link.l }}%;
        --bulma-warning-h: {{ warning.h }}deg;
        --bulma-warning-s: {{ warning.s }}%;
        --bulma-warning-l: {{ warning.l }}%;
        --bulma-danger-h: {{ danger.h }}deg;
        --bulma-danger-s: {{ danger.s }}%;
        --bulma-danger-l: {{ danger.l }}%;
    }
</style>