# Generated by Django 5.2.8 on 2026-02-07 13:13

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('sequence', '0003_alter_sequence_tenant'),
    ]

    operations = [
        migrations.AddField(
            model_name='sequence',
            name='has_subsequence_per_year',
            field=models.BooleanField(default=False, verbose_name='Subsequence per year'),
        ),
        migrations.AddField(
            model_name='sequence',
            name='padding',
            field=models.IntegerField(default=0, help_text='Pads the sequence with zeros to the given length.', validators=[django.core.validators.MaxLengthValidator(10)], verbose_name='Padding'),
        ),
        migrations.AddField(
            model_name='sequence',
            name='prefix',
            field=models.CharField(default='', verbose_name='Prefix'),
        ),
    ]
