{% load i18n %}

<a class="navbar-item" href="{% url 'user:detail' %}?tenant_id={{ request.tenant.pk }}" hx-boost="false">{% translate 'Preferences' %}</a>
{% if request.user.is_staff %}
    <a class="navbar-item" hx-boost="false" href="/admin/">Admin</a>
{% endif %}
<hr class="navbar-divider">
<a class="navbar-item" hx-post="{% url 'user:logout' %}">{% translate "Log out" %}</a>


