{% load i18n %}
{% load static %}
{% load cache %}
{% load ui %}
{% load partials %}

<div id="filter" x-data="filter">
    
    <div id="query-tags" x-ref="queryTags" class="mb-1">
        {{ ui_filter.query_tags }}
    </div>
    
    <div id="query-input" class="">
        {{ ui_filter.query_input }}
    </div>
    
    <div class="mb-6" style="width: 100%" x-show="showParams" x-cloak="" x-on:click.outside="showParams = false;" x-transition.duration.150ms>
        {{ ui_filter.query_params }}
    </div>

    <div id="query-apply" x-ref="queryApply"
         hx-trigger="click" hx-replace-url="true"
         hx-target="#overview-container"
         hx-select="#overview-container"
         hx-select-oob="#query-tags,#query-apply">
    </div>
</div>
