# Generated by Django 5.2.1 on 2025-05-24 09:10

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('accrete', '0007_accessgroup_description'),
    ]

    operations = [
        migrations.AlterField(
            model_name='member',
            name='access_groups',
            field=models.ManyToManyField(blank=True, through='accrete.MemberAccessGroupRel', through_fields=('member', 'access_group'), to='accrete.accessgroup'),
        ),
        migrations.AlterField(
            model_name='tenant',
            name='access_groups',
            field=models.ManyToManyField(blank=True, through='accrete.TenantAccessGroupRel', through_fields=('tenant', 'access_group'), to='accrete.accessgroup'),
        ),
    ]
