# Generated by Django 5.1.4 on 2025-02-19 16:59

import accrete.fields
import django.db.models.functions.text
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Country',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', accrete.fields.TranslatedCharField(verbose_name='Name')),
                ('iso_code_a2', models.CharField(max_length=2, verbose_name='ISO Code Alpha 2')),
                ('iso_code_a3', models.CharField(max_length=3, verbose_name='ISO Code Alpha 3')),
                ('vat_prefix', models.CharField(blank=True, max_length=3, null=True, verbose_name='VAT ID Prefix')),
                ('order_priority', models.IntegerField(default=0, verbose_name='Order Priority')),
            ],
            options={
                'verbose_name': 'Country',
                'verbose_name_plural': 'Countries',
                'db_table': 'accrete_country',
                'ordering': ['-order_priority', django.db.models.functions.text.Lower('name')],
            },
        ),
    ]
