# Generated by Django 5.2.8 on 2026-02-11 10:03

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('sequence', '0004_sequence_has_subsequence_per_year_sequence_padding_and_more'),
    ]

    operations = [
        migrations.AlterField(
            model_name='sequence',
            name='padding',
            field=models.IntegerField(default=0, help_text='Pads the sequence with zeros to the given length.', validators=[django.core.validators.MaxValueValidator(10)], verbose_name='Padding'),
        ),
    ]
