# Generated by Django 5.2.7 on 2025-10-06 18:59

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('log', '0006_remove_log_accrete_log_model_cf888c_idx_and_more'),
    ]

    operations = [
        migrations.AlterField(
            model_name='log',
            name='new_value_type',
            field=models.CharField(choices=[('fk', 'Foreign Key'), ('int', 'Integer'), ('float', 'Float'), ('decimal', 'Decimal'), ('bool', 'Boolean'), ('str', 'String'), ('date', 'Date'), ('datetime', 'Date Time'), ('json', 'JSON')], max_length=100, verbose_name='New Value Type'),
        ),
        migrations.AlterField(
            model_name='log',
            name='old_value_type',
            field=models.CharField(choices=[('fk', 'Foreign Key'), ('int', 'Integer'), ('float', 'Float'), ('decimal', 'Decimal'), ('bool', 'Boolean'), ('str', 'String'), ('date', 'Date'), ('datetime', 'Date Time'), ('json', 'JSON')], max_length=100, verbose_name='Old Value Type'),
        ),
    ]
